.. pvlab documentation master file, created by
   sphinx-quickstart on Fri Jul 23 09:22:51 2021.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

Welcome to pvlab's documentation!
=================================

.. toctree::
   :maxdepth: 3
   :caption: Table of Contents
   :numbered: 1

   /usage/en/LICENSE
   /usage/en/README
   /usage/en/whatsnew
   /usage/en/installation
   /usage/en/tools_dataframes
   /usage/en/tools_math


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
